@@ -26,9 +26,9 @@ if sys.platform.startswith('win'):
     DYNAMIPS_DEFAULT_PATH = unicode('dynamips.exe')
 elif sys.platform.startswith('darwin'):
     if hasattr(sys, "frozen"):
-        DYNAMIPS_DEFAULT_PATH = os.getcwdu() + os.sep + '../Resources/dynamips-0.2.10-OSX.intel64.bin'
+        DYNAMIPS_DEFAULT_PATH = os.getcwdu() + os.sep + '../Resources/dynamips'
     else:
-        DYNAMIPS_DEFAULT_PATH = os.getcwdu() + os.sep + 'dynamips-0.2.10-OSX.intel64.bin'
+        DYNAMIPS_DEFAULT_PATH = os.getcwdu() + os.sep + 'dynamips'
 else:
     DYNAMIPS_DEFAULT_PATH = unicode('dynamips')
 
