@@ -57,9 +57,9 @@ class IOSDialog(QtGui.QDialog, Ui_IOSDialog):
         IOS images and hypervisors management
     """
 
-    def __init__(self):
+    def __init__(self, parent=None):
 
-        QtGui.QDialog.__init__(self)
+        QtGui.QDialog.__init__(self, parent)
         self.setupUi(self)
 
         # connections to slots
